use PerformanceCollection;
go

--list Organizations
select * from Organization


--list Servers at this Organization (#5)
select ServerID, OrganizationID, ServerName from dbo.Server where OrganizationID = 5

--use whatever method you wish to get perfmon data into this database
--I recommend Midnight DBAs Perfmon BLG loader
--http://midnightdba.itbookworm.com/Events, Demo code from SQL Sat OK #309 - DIY Performance Reporting

--show raw CPU statistics
select * from dbo.CPU where ServerID = 9

select count(1) as CPUCount from dbo.CPU where ServerID = 9

select top 100 * from dbo.CPUPerformance where CPUID = 4 order by CollectionDT

--show min/avg/max
select 
	avg(cp.PercentUserTime) as AvgPercentUserTime, 
	avg(cp.PercentPrivTime) as AvgPercentPrivTime, 
	min(cp.PercentUserTime) as MinPercentUserTime, 
	min(cp.PercentPrivTime) as MinPercentPrivTime,
	max(cp.PercentUserTime) as MaxPercentUserTime, 
	max(cp.PercentPrivTime) as MaxPercentPrivTime,
	c.CPUNum
from 
	CPUPerformance cp 
	left join CPU c on c.CPUID = cp.CPUID
	left join Server s on s.ServerID = c.ServerID
where
	s.ServerID = 9
group by c.CPUNum
order by CPUNum

--get median by core (better representation of central tendency than average)
select distinct
	PERCENTILE_CONT(0.5) within group (order by cp.PercentUserTime) over (partition by cp.CPUID) as MedianPercentUserTime,
	c.CPUNum
from 
	CPUPerformance cp 
	left join CPU c on c.CPUID = cp.CPUID
	left join Server s on s.ServerID = c.ServerID
where
	s.ServerID = 9
group by c.CPUNum, cp.CPUID, cp.PercentUserTime
order by CPUNum


--CPU performance percentile analysis
--yes, sql server 2014 has percentile_disc. I'm not assuming you're on 2014 yet.

--how many cores?
select count(1) as CPUCount from dbo.CPU where ServerID = 10
exec dbo.CPUPerformance_ByServer 10

select count(1) as CPUCount from dbo.CPU where ServerID = 11
exec dbo.CPUPerformance_ByServer 11
--where do these systems lie? does it need more or less resources?


select count(1) as CPUCount from dbo.CPU where ServerID = 9
exec dbo.CPUPerformance_ByServer 9
--what about this one?



--what about filtering by just the business day?
--filters 8a-6p, Mon-Fri
exec dbo.CPUPerformance_BizDayByServer 11
exec dbo.CPUPerformance_BizDayByServer 9
--compare to 24/7 and what is running outside of business hours?

--get data points for averages by core
--averages by 15 minute intervals, for 24h in a day
exec dbo.CPUPerformance_IntervalByServer 11

--memory
--averages across the server
exec dbo.MemoryPerformance_ByServer 9


--disk
exec dbo.Disk_GetListByServerID 9

--percentile analysis by drive
exec dbo.DiskPerformance_ByMountpoint 9, 'D:'
exec dbo.DiskPerformance_ByMountpoint 9, 'L:'
exec dbo.DiskPerformance_ByMountpoint 9, 'G:'

exec dbo.DiskPerformance_BizDayByMountpoint 9, 'G:'
